/**
 * OW2 Util
 * Copyright (C) 2008 SERLI
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: ObrResourceFetcherFactory.java 4392 2008-12-15 14:05:41Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.plan.fetcher.impl.obr;

import org.osgi.framework.BundleContext;
import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.bindings.deploymentplan.obr.ObrDeployment;
import org.ow2.util.plan.fetcher.api.IResourceFetcher;
import org.ow2.util.plan.fetcher.api.IResourceFetcherFactory;
import org.ow2.util.plan.fetcher.api.exceptions.FetcherFactoryException;
import org.ow2.util.plan.fetcher.impl.AbsResourceFetcherFactoryImpl;

/**
 * Factory of ObrResourceFetcher objects.
 * @author Mickaël LEDUQUE
 */
public class ObrResourceFetcherFactory extends AbsResourceFetcherFactoryImpl implements IResourceFetcherFactory {

    /**
     * The bundle context.
     */
    private BundleContext bundleContext = null;

    /**
     * Default constructor.
     */
    public ObrResourceFetcherFactory() {
        this.setFetcherConcreteClass(ObrResourceFetcher.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public IResourceFetcher getResourceFetcher(final DeploymentPlanFragment fragment) throws FetcherFactoryException {
        ObrResourceFetcher obrResourceFetcher = (ObrResourceFetcher) super.getResourceFetcher(fragment);
        obrResourceFetcher.setBundleContext(this.bundleContext);
        return obrResourceFetcher;
    }

    /**
     * {@inheritDoc}
     */
    public Class<? extends DeploymentPlanFragment> getSupportedClass() {
        return ObrDeployment.class;
    }

    /**
     * Sets the bundle context.
     * @param bundleContext the new bundle context.
     */
    public void setBundleContext(final BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }

    /**
     * Returns the bundle context.
     * @return the bundle context.
     */
    public BundleContext getBundleContext() {
        return this.bundleContext;
    }
}
